@@ -8,6 +8,7 @@ from dh_client.entities.glossary_terms import GlossaryTerm
 from dh_client.entities.links import Link
 from dh_client.entities.owners import Owner
 from dh_client.entities.tags import Tag
+from dh_client.utils import str_or_md_file
 
 
 class Dashboard(Entity):
@@ -55,6 +56,7 @@ class Dashboard(Entity):
         url: str = None,
         links: Dict[str, str] = None,
         platform: str = "datastudio",
+        create_chart: bool = True,
     ) -> List[dict]:
         """Create a dashboard mpc.
 
@@ -69,37 +71,43 @@ class Dashboard(Entity):
             url: The url.
             links: List of links.
             platform: The platform.
+            create_chart: Create the same chart or not.
 
 
         Returns: A list with a single mpc dictionary.
         """
         inputs = inputs or []
         dashboard_urn = self._get_dashboard_urn(name, platform)
+        mpc = []
+        description = str_or_md_file(description)
 
-        mpc = [
-            self._create_mpc_dict(
-                "chart",
-                self._get_chart_urn(name, platform),
-                "chartInfo",
-                models.ChartInfoClass(
-                    title=title if title else name,
-                    description=description,
-                    externalUrl=url,
-                    lastModified=models.ChangeAuditStampsClass(
-                        created=models.AuditStampClass(
-                            time=0, actor=self.emmiter.datahub_actor
-                        )
+        if create_chart:
+            mpc.append(
+                self._create_mpc_dict(
+                    "chart",
+                    self._get_chart_urn(name, platform),
+                    "chartInfo",
+                    models.ChartInfoClass(
+                        title=title if title else name,
+                        description="",
+                        externalUrl=url,
+                        lastModified=models.ChangeAuditStampsClass(
+                            created=models.AuditStampClass(
+                                time=0, actor=self.emmiter.datahub_actor
+                            )
+                        ),
+                        inputs=[
+                            builder.make_dataset_urn(
+                                platform=self.emmiter.dataset_platform,
+                                name=input_,
+                                env=self.emmiter.env,
+                            )
+                            for input_ in inputs
+                        ],
                     ),
-                    inputs=[
-                        builder.make_dataset_urn(
-                            platform=self.emmiter.dataset_platform,
-                            name=input_,
-                            env=self.emmiter.env,
-                        )
-                        for input_ in inputs
-                    ],
-                ),
-            ),
+                )
+            )
+        mpc.append(
             self._create_mpc_dict(
                 self.entity_type,
                 dashboard_urn,
@@ -108,7 +116,9 @@ class Dashboard(Entity):
                     title=title if title else name,
                     description=description,
                     externalUrl=url,
-                    charts=[self._get_chart_urn(name, platform)],
+                    charts=[self._get_chart_urn(name, platform)]
+                    if create_chart
+                    else None,
                     lastModified=models.ChangeAuditStampsClass(
                         created=models.AuditStampClass(
                             time=0, actor=self.emmiter.datahub_actor
@@ -116,7 +126,7 @@ class Dashboard(Entity):
                     ),
                 ),
             ),
-        ]
+        )
 
         if tags:
             mpc.append(
