@@ -77,12 +77,25 @@ class Dataset(Entity):
                 entityType=Dataset.entity_type,
                 entityUrn=dataset_urn,
                 aspectName=Dataset.aspect_name,
-                aspect=models.DatasetPropertiesClass(
-                    description=str_or_md_file(description), externalUrl=url
-                ),
+                aspect=models.DatasetPropertiesClass(externalUrl=url),
             )
         ]
 
+        if description:
+            mpc.append(
+                dict(
+                    entityType=Dataset.entity_type,
+                    entityUrn=dataset_urn,
+                    aspectName="editableDatasetProperties",
+                    aspect=models.EditableDatasetPropertiesClass(
+                        created=models.AuditStampClass(
+                            time=0, actor=self.emmiter.datahub_actor
+                        ),
+                        description=str_or_md_file(description),
+                    ),
+                )
+            )
+
         if tags:
             mpc.append(Tag.create_mpc_association(self.entity_type, dataset_urn, tags))
         if owners:
